@@ -4,6 +4,7 @@ import io
 import logging
 import os
 import time
+import struct
 from datetime import timedelta, datetime
 
 import pkg_resources
@@ -23,7 +24,10 @@ from mgzdb.util import parse_filename, save_file, get_unique
 from mgzdb.compress import compress, compress_tiles, compress_objects
 from mgzdb.extract import save_extraction
 from mgz.util import Version
-from mgz.summary.chat import Chat as ChatType
+try:
+    from mgz.common.chat import Chat as ChatType
+except ImportError:
+      from mgz.summary.chat import Chat as ChatType
 
 
 LOGGER = logging.getLogger(__name__)
@@ -217,12 +221,20 @@ class AddFile:
                 if not match:
                     return False, message
                 self._update_match_users(platform_id, match.id, user_data)
-                self._update_match_de(match)
+                self._update_match_hd(match)
+                self._update_match_dashboard(match, user_data)
             except IntegrityError:
                 LOGGER.error("[f:%s] constraint violation: could not add match", log_id)
                 return False, 'Failed to add match'
+            except MemoryError:
+                LOGGER.error("[f:%s] compression failed", log_id)
+                return False, 'Compression failed'
 
-        compressed_filename, compressed_size = self._handle_file(file_hash, data, Version(match.version_id))
+        try:
+            compressed_filename, compressed_size = self._handle_file(file_hash, data, Version(match.version_id))
+        except MemoryError:
+            LOGGER.error("[f:%s] compression failed", log_id)
+            return False, 'Compression failed'
 
         try:
             new_file = get_unique(
@@ -314,10 +326,12 @@ class AddFile:
             return False, 'Dataset not supported'
 
         series, tournament, event, event_map_id = self._handle_series(series_id, series_name, map_data, log_id)
-        if series and series.played:
-            played = series.played
 
         objects = summary.get_objects()
+        try:
+            compressed_objects = compress_objects(objects['objects'])
+        except struct.error:
+            return False, "bad object parsing"
 
         match = get_unique(
             self.session,
@@ -340,7 +354,7 @@ class AddFile:
             ladder_id=ladder_id,
             rated=rated,
             lobby_name=platform_data['lobby_name'],
-            objects=compress_objects(objects['objects']),
+            objects=compressed_objects,
             builtin_map_id=map_data['id'],
             event_map_id=event_map_id,
             map_size_id=map_data['dimension'],
@@ -474,38 +488,29 @@ class AddFile:
         save_chat(self.session, summary.get_chat(), match.id)
         return match, None
 
-    def _update_match_de(self, match):
+    def _update_match_dashboard(self, match, user_data):
         if match.platform_id != 'de':
             return
-        field = 'uuid'
-        if match.platform_match_id.isdigit():
-            field = 'match_id'
-        resp = requests.get('https://aoe2.net/api/match?{}={}'.format(field, match.platform_match_id))
-        if resp.status_code != 200:
-            LOGGER.warning('failed to get aoe2.net data')
+        lookup = {str(u['user_id']):u for u in user_data if 'user_id' in u}
+        for player in match.players:
+            ref = lookup.get(player.user_id)
+            if not ref:
+                continue
+            player.random = ref.get('random')
+            player.full_random = ref.get('full_random')
+            player.mirror = ref.get('mirror')
+            player.rate_snapshot = ref.get('rating')
+            player.vod = ref.get('vod')
+
+
+    def _update_match_hd(self, match):
+        if match.platform_id != 'hd':
             return
-        data = resp.json()
-        if data['started']:
-            match.played = datetime.fromtimestamp(data['started'])
-        match.rated = data['ranked']
-        match.lobby_private = data['has_password']
-        match.lobby_opened = datetime.fromtimestamp(data['opened'])
-        match.server = data['server']
-        match.ladder_id = data['leaderboard_id']
-        if data['version']:
-            match.build = '101.101.{}.0'.format(data['version'])
-            match.dataset_version = match.build
-        for pdata in data['players']:
-            if not pdata['profile_id']:
-                continue
-            try:
-                player = self.session.query(Player).filter_by(match_id=match.id, user_id=str(pdata['profile_id'])).one()
-            except NoResultFound:
-                LOGGER.error("failed to find p%d to update platform user data", p['color'])
-                continue
-            LOGGER.info("[m:%s] updating platform user data for p%d", match.hash[:LOG_ID_LENGTH], pdata['color'])
-            get_unique(self.session, User, ['id', 'platform_id'], id=str(pdata['profile_id']), platform_id=match.platform_id)
-            player.rate_snapshot = pdata['rating']
+        if match.rated:
+            if match.type_id == 0:
+                match.ladder_id = 0
+            elif match.type_id == 2:
+                match.ladder_id = 1
 
 
     def _update_match_users(self, platform_id, match_id, user_data):
@@ -533,6 +538,9 @@ class AddFile:
             player.platform_id = platform_id
             player.rate_before = user.get('rate_before')
             player.rate_after = user.get('rate_after')
+            player.random = user.get('random')
+            player.full_random = user.get('full_random')
+            player.mirror = user.get('mirror')
             if not player.rate_snapshot:
                 player.rate_snapshot = user.get('rate_snapshot')
 
