@@ -66,6 +66,7 @@ class Tournament(BASE):
     __tablename__ = 'tournaments'
     id = Column(String, primary_key=True)
     name = Column(String)
+    url = Column(String)
     event_id = Column(String, ForeignKey('events.id'), index=True)
     event = relationship('Event', foreign_keys=[event_id], backref='tournaments')
 
@@ -426,6 +427,10 @@ class Player(BASE):
     rate_before = Column(Float)
     rate_after = Column(Float, index=True)
     rate_snapshot = Column(Float, index=True)
+    random = Column(Boolean)
+    full_random = Column(Boolean)
+    mirror = Column(Boolean)
+    vod = Column(String, index=True)
     military_score = Column(Integer)
     units_killed = Column(Integer)
     hit_points_killed = Column(Integer)
@@ -734,3 +739,19 @@ class HiddenCupPlayers(BASE):
     hc_name = Column(String, primary_key=True)
     person_name = Column(String, primary_key=True)
     event_id = Column(String)
+
+
+class MatchmakingLog(BASE):
+    __tablename__ = 'matchmaking_log'
+    id = Column(Integer, primary_key=True)
+    map_name = Column(String)
+    status = Column(String)
+    played = Column(DateTime)
+
+
+class MatchmakingPlayerLog(BASE):
+    """Log special matches."""
+    __tablename__ = 'matchmaking_player_log'
+    match_id = Column(Integer, ForeignKey('matchmaking_log.id', ondelete='cascade'), primary_key=True)
+    user_id = Column(Integer, primary_key=True)
+    status = Column(String)
