@@ -10,6 +10,7 @@ from sqlalchemy.exc import IntegrityError
 
 MGZ_EXT = '.mgz'
 DE_EXT = '.aoe2record'
+HD_EXT = '.aoe2record'
 MGX_EXT = '.mgx'
 ZIP_EXT = '.zip'
 CHALLONGE_ID_LENGTH = 9
@@ -73,28 +74,53 @@ def parse_filename(filename):
     mgz_parts = parse_filename_mgz(filename)
     mgx_parts = parse_filename_mgx(filename)
     de_parts = parse_filename_de(filename)
+    hd_parts = parse_filename_hd(filename)
     if mgz_parts[0]:
         return mgz_parts
     if mgx_parts[0]:
         return mgx_parts
     if de_parts[0]:
         return de_parts
+    if hd_parts[0]:
+        return hd_parts
     return None, None
 
 
+def parse_filename_hd(filename):
+    """Parse a HD Edition filename."""
+    if not filename.startswith('MP Replay') or not filename.endswith(HD_EXT) or len(filename) < 38:
+        return None, None
+    start = filename.find('@') + 1
+    if not start:
+        return None, None
+    try:
+        return datetime(
+            year=int(filename[start:start+4]),
+            month=int(filename[start+5:start+7]),
+            day=int(filename[start+8:start+10]),
+            hour=int(filename[start+11:start+13]),
+            minute=int(filename[start+13:start+15]),
+            second=int(filename[start+15:start+17])
+        ), filename[11:15].strip()
+    except ValueError:
+        return None, None
+
+
 def parse_filename_de(filename):
     """Parse a Definitive Edition filename."""
     if not filename.startswith('MP Replay') or not filename.endswith(DE_EXT) or len(filename) < 45:
         return None, None
-    return datetime(
-        year=int(filename[28:32]),
-        month=int(filename[33:35]),
-        day=int(filename[36:38]),
-        hour=int(filename[39:41]),
-        minute=int(filename[41:43]),
-        second=int(filename[43:45])
-    ), filename[11:26]
-
+    try:
+        return datetime(
+            year=int(filename[28:32]),
+            month=int(filename[33:35]),
+            day=int(filename[36:38]),
+            hour=int(filename[39:41]),
+            minute=int(filename[41:43]),
+            second=int(filename[43:45])
+        ), filename[11:26]
+    except ValueError:
+        return None, None
 
 def parse_filename_mgz(filename):
     """Parse a Userpatch filename."""
